@@ -3,19 +3,22 @@ from __future__ import annotations
 from copy import deepcopy
 from pprint import pprint
 from typing import TYPE_CHECKING, Dict, Generator, List, Tuple
+
 from aasm.utils.exception import PanicException
 
 if TYPE_CHECKING:
     from aasm.intermediate.action import Action
     from aasm.intermediate.agent import Agent
     from aasm.intermediate.behaviour import Behaviour
+    from aasm.intermediate.graph import Graph
     from aasm.intermediate.message import Message
 
 
 class ParsedData:
-    def __init__(self, agents: List[Agent], messages: List[Message]):
+    def __init__(self, agents: List[Agent], messages: List[Message], graph: Graph):
         self.agents: List[Agent] = agents
         self.messages: List[Message] = messages
+        self.graph: Graph = graph
 
 
 class State:
@@ -27,8 +30,10 @@ class State:
         self.in_message: bool = False
         self.in_behaviour: bool = False
         self.in_action: bool = False
+        self.in_graph: bool = False
         self.agents: Dict[str, Agent] = {}
         self.messages: Dict[Tuple[str, str], Message] = {}
+        self.graph: Graph = None
         
     @property
     def last_agent(self) -> Agent:
@@ -51,12 +56,18 @@ class State:
         
     def add_message(self, message: Message) -> None:
         self.messages[(message.type, message.performative)] = message
+
+    def add_graph(self, graph: Graph) -> None:
+        self.graph = graph
         
     def agent_exists(self, name: str) -> bool:
         return name in self.agents
     
     def message_exists(self, msg_type: str, msg_performative: str) -> bool:
         return (msg_type, msg_performative) in self.messages
+
+    def graph_exists(self) -> bool:
+        return self.graph is not None
     
     def get_message_instance(self, msg_type: str, msg_performative: str) -> Message:
         return deepcopy(self.messages[(msg_type, msg_performative)])
@@ -71,27 +82,34 @@ class State:
                 yield tokens
                 
     def print(self) -> None:
-        print('- Messages:')
-        for message in self.messages.values():
-            message.print()
-            print('')
-        print('- Agents:')
-        for agent in self.agents.values():
-            agent.print()
-            print('')
-        
+        if self.messages:
+            print('- Messages:')
+            for message in self.messages.values():
+                message.print()
+                print('')
+        if self.agents:
+            print('- Agents:')
+            for agent in self.agents.values():
+                agent.print()
+                print('')
+        if self.graph:
+            print('- Graph:')
+            self.graph.print()
+    
     def verify_end_state(self) -> None:
         if self.in_agent:
             self.panic('Missing EAGENT')
         elif self.in_message:
             self.panic('Missing EMESSAGE')
+        elif self.in_graph:
+            self.panic('Missing EGRAPH')
             
     def get_parsed_data(self) -> ParsedData:
         self.verify_end_state()
         if self.debug:
             pprint(self.__dict__)
             self.print()
-        return ParsedData(list(self.agents.values()), list(self.messages.values()))
+        return ParsedData(list(self.agents.values()), list(self.messages.values()), self.graph)
 
     def panic(self, reason: str, suggestion: str = '') -> None:
         if self.debug:
